You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@storm.apache.org by ki...@apache.org on 2015/11/18 21:03:36 UTC

[4/8] storm git commit: Use generic name bugtracker instead of jira and use public domain images

Use generic name bugtracker instead of jira and use public domain images


Project: http://git-wip-us.apache.org/repos/asf/storm/repo
Commit: http://git-wip-us.apache.org/repos/asf/storm/commit/b64998f8
Tree: http://git-wip-us.apache.org/repos/asf/storm/tree/b64998f8
Diff: http://git-wip-us.apache.org/repos/asf/storm/diff/b64998f8

Branch: refs/heads/master
Commit: b64998f846ed4d60ea6a9662d88f8a2d6353b110
Parents: d0575b9
Author: Kishor Patil <kp...@yahoo-inc.com>
Authored: Thu Nov 12 17:03:28 2015 +0000
Committer: Kishor Patil <kp...@yahoo-inc.com>
Committed: Thu Nov 12 17:03:28 2015 +0000

----------------------------------------------------------------------
 storm-core/src/clj/backtype/storm/ui/core.clj     |   2 +-
 storm-core/src/jvm/backtype/storm/Config.java     |   8 ++++----
 storm-core/src/ui/public/images/bug.png           | Bin 0 -> 4045 bytes
 storm-core/src/ui/public/images/jira.png          | Bin 3720 -> 0 bytes
 storm-core/src/ui/public/images/statistic.png     | Bin 3751 -> 488 bytes
 .../src/ui/public/templates/user-template.html    |   8 ++++----
 6 files changed, 9 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/storm/blob/b64998f8/storm-core/src/clj/backtype/storm/ui/core.clj
----------------------------------------------------------------------
diff --git a/storm-core/src/clj/backtype/storm/ui/core.clj b/storm-core/src/clj/backtype/storm/ui/core.clj
index 6d74f2a..99f75e4 100644
--- a/storm-core/src/clj/backtype/storm/ui/core.clj
+++ b/storm-core/src/clj/backtype/storm/ui/core.clj
@@ -922,7 +922,7 @@
     (assert-authorized-user "getClusterInfo")
     (let [user (get-user-name servlet-request)]
       (json-response (assoc (cluster-summary user)
-                          "jira-url" (*STORM-CONF* UI-PROJECT-JIRA-URL)
+                          "bugtracker-url" (*STORM-CONF* UI-PROJECT-BUGTRACKER-URL)
                           "central-log-url" (*STORM-CONF* UI-CENTRAL-LOGGING-URL)) (:callback m))))
   (GET "/api/v1/nimbus/summary" [:as {:keys [cookies servlet-request]} & m]
     (mark! ui:num-nimbus-summary-http-requests)

http://git-wip-us.apache.org/repos/asf/storm/blob/b64998f8/storm-core/src/jvm/backtype/storm/Config.java
----------------------------------------------------------------------
diff --git a/storm-core/src/ui/public/images/bug.png b/storm-core/src/ui/public/images/bug.png
new file mode 100644
index 0000000..e98e156
Binary files /dev/null and b/storm-core/src/ui/public/images/bug.png differ

http://git-wip-us.apache.org/repos/asf/storm/blob/b64998f8/storm-core/src/ui/public/images/jira.png
----------------------------------------------------------------------
diff --git a/storm-core/src/ui/public/images/jira.png b/storm-core/src/ui/public/images/jira.png
deleted file mode 100644
index 8a45d98..0000000
Binary files a/storm-core/src/ui/public/images/jira.png and /dev/null differ

http://git-wip-us.apache.org/repos/asf/storm/blob/b64998f8/storm-core/src/ui/public/images/statistic.png
----------------------------------------------------------------------
diff --git a/storm-core/src/ui/public/images/statistic.png b/storm-core/src/ui/public/images/statistic.png
index 5ebad79..f9ad38a 100644
Binary files a/storm-core/src/ui/public/images/statistic.png and b/storm-core/src/ui/public/images/statistic.png differ

http://git-wip-us.apache.org/repos/asf/storm/blob/b64998f8/storm-core/src/ui/public/templates/user-template.html
----------------------------------------------------------------------
diff --git a/storm-core/src/ui/public/templates/user-template.html b/storm-core/src/ui/public/templates/user-template.html
index 7e3cc00..853f0c9 100644
--- a/storm-core/src/ui/public/templates/user-template.html
+++ b/storm-core/src/ui/public/templates/user-template.html
@@ -21,11 +21,11 @@
                 <a href="{{central-log-url}}" target="_blank"><image src="/images/statistic.png" class="image_pre_format"/></a>
         </span>
       {{/central-log-url}}
-     {{#jira-url}}
-        <span data-toggle="tooltip" data-placement="bottom" data-original-title="Submit Jira for Help.">
-                <a href="{{jira-url}}" target="_blank"><image src="/images/jira.png" class="image_pre_format"/></a>
+     {{#bugtracker-url}}
+        <span data-toggle="tooltip" data-placement="bottom" data-original-title="Submit BUG for Help and tracking the issue.">
+                <a href="{{bugtracker-url}}" target="_blank"><image src="/images/bug.png" class="image_pre_format"/></a>
         </span>
-     {{/jira-url}}
+     {{/bugtracker-url}}
      <span data-toggle="tooltip" data-placement="bottom" data-original-title="Search through all logs for any topology.">
              <a href="/deep_search_result.html" target="_blank"><image src="/images/search.png" class="image_pre_format"/></a>
      </span>
diff --git a/storm-core/src/jvm/backtype/storm/Config.java b/storm-core/src/jvm/backtype/storm/Config.java
index 69ff4b7..a8cd300 100644
--- a/storm-core/src/jvm/backtype/storm/Config.java
+++ b/storm-core/src/jvm/backtype/storm/Config.java
@@ -570,16 +570,16 @@ public class Config extends HashMap<String, Object> {
     public static final String UI_PORT = "ui.port";
 
     /**
      * Storm UI Project JIRA Link for reporting issue.
      */
-    public static final String UI_PROJECT_JIRA_URL = "ui.project.jira.url";
-    public static final Object UI_PROJECT_JIRA_URL_SCHEMA = String.class;
+    @isString
+    public static final String UI_PROJECT_BUGTRACKER_URL = "ui.project.bugtracker.url";
 
     /**
      * Storm UI Central Logging URL.
      */
+    @isString
     public static final String UI_CENTRAL_LOGGING_URL = "ui.central.logging.url";
-    public static final Object UI_CENTRAL_LOGGING_URL_SCHEMA = String.class;
 
     /**
      * HTTP UI port for log viewer

http://git-wip-us.apache.org/repos/asf/storm/blob/b64998f8/storm-core/src/ui/public/images/bug.png
----------------------------------------------------------------------
@@ -570,16 +570,16 @@ public class Config extends HashMap<String, Object> {
 
     /**
-     * Storm UI Project JIRA Link for reporting issue.
+     * Storm UI Project BUGTRACKER Link for reporting issue.
      */